pub struct assertApproxEqRel_3Return {}Expand description
Compares two int256 values. Expects relative difference in percents to be less than or equal to maxPercentDelta.
maxPercentDelta is an 18 decimal fixed point number, where 1e18 == 100%
Includes error message into revert string on failure.
Container type for the return parameters of the assertApproxEqRel(int256,int256,uint256,string) function.
Implementations
Sourceimpl assertApproxEqRel_3Return
impl assertApproxEqRel_3Return
fn _tokenize(&self) -> <assertApproxEqRel_3Call as SolCall>::ReturnToken<'_>