pub struct broadcastRawTransactionReturn {}Expand description
Takes a signed transaction and broadcasts it to the network.
Container type for the return parameters of the broadcastRawTransaction(bytes) function.
Implementations
Sourceimpl broadcastRawTransactionReturn
impl broadcastRawTransactionReturn
fn _tokenize(&self) -> <broadcastRawTransactionCall as SolCall>::ReturnToken<'_>