pub struct currentFilePathReturn {
pub path: String,
}Expand description
Get the source file path of the currently running test or script contract,
relative to the project root.
Container type for the return parameters of the currentFilePath() function.
Fields
path: StringTrait Implementations
Sourceimpl Clone for currentFilePathReturn
impl Clone for currentFilePathReturn
Sourcefn clone(&self) -> currentFilePathReturn
fn clone(&self) -> currentFilePathReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for currentFilePathReturn
impl RefUnwindSafe for currentFilePathReturn
impl Send for currentFilePathReturn
impl Sync for currentFilePathReturn
impl Unpin for currentFilePathReturn
impl UnsafeUnpin for currentFilePathReturn
impl UnwindSafe for currentFilePathReturn