pub struct deriveKey_0Return {
pub privateKey: U256,
}Expand description
Derive a private key from a provided mnemonic string (or mnemonic file path)
at the derivation path m/44'/60'/0'/0/{index}.
Container type for the return parameters of the deriveKey(string,uint32) function.
Fields
privateKey: U256Trait Implementations
Sourceimpl Clone for deriveKey_0Return
impl Clone for deriveKey_0Return