pub struct ecAddAffineCall {
pub pointX1: U256,
pub pointY1: U256,
pub pointX2: U256,
pub pointY2: U256,
}Expand description
Adds the secp256k1 affine points point1 = (pointX1, pointY1) and
point2 = (pointX2, pointY2).
The point at infinity is represented as (0, 0).
Function with signature ecAddAffine(uint256,uint256,uint256,uint256) and selector 0x1af9eefc.
function ecAddAffine(uint256 pointX1, uint256 pointY1, uint256 pointX2, uint256 pointY2) external pure returns (uint256 resultX, uint256 resultY);Fields
pointX1: U256pointY1: U256pointX2: U256pointY2: U256Trait Implementations
Sourceimpl CheatcodeDef for ecAddAffineCall
impl CheatcodeDef for ecAddAffineCall
Sourceimpl Clone for ecAddAffineCall
impl Clone for ecAddAffineCall
Sourcefn clone(&self) -> ecAddAffineCall
fn clone(&self) -> ecAddAffineCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ecAddAffineCall
impl Debug for ecAddAffineCall
Sourceimpl JsonAbiExt for ecAddAffineCall
impl JsonAbiExt for ecAddAffineCall
Sourceimpl SolCall for ecAddAffineCall
impl SolCall for ecAddAffineCall
Sourceconst SIGNATURE: &'static str = "ecAddAffine(uint256,uint256,uint256,uint256)"
const SIGNATURE: &'static str = "ecAddAffine(uint256,uint256,uint256,uint256)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<256>, Uint<256>, Uint<256>, Uint<256>)
type Parameters<'a> = (Uint<256>, Uint<256>, Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<ecAddAffineCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<ecAddAffineCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = ecAddAffineReturn
type Return = ecAddAffineReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Uint<256>, Uint<256>)
type ReturnTuple<'a> = (Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<ecAddAffineCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<ecAddAffineCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self::Return>
fn abi_decode_returns_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self::Return>
ABI-decodes this call’s return values with a custom decoder configuration.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self, Error>
fn abi_decode_raw_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self, Error>
ABI-decodes this call’s arguments with a custom decoder configuration,
without its selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self, Error>
fn abi_decode_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self, Error>
ABI-decodes this call’s arguments with a custom decoder configuration.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.