pub struct ecAddProjectiveCall {
pub pointX1: U256,
pub pointY1: U256,
pub pointZ1: U256,
pub pointX2: U256,
pub pointY2: U256,
pub pointZ2: U256,
}Expand description
Adds the secp256k1 projective points point1 = (pointX1, pointY1, pointZ1) and
point2 = (pointX2, pointY2, pointZ2).
The point at infinity is accepted as (0, y, 0) for any non-zero y and returned as
(0, 1, 0). Any other result is normalized to (x, y, 1).
Function with signature ecAddProjective(uint256,uint256,uint256,uint256,uint256,uint256) and selector 0x45b12879.
function ecAddProjective(uint256 pointX1, uint256 pointY1, uint256 pointZ1, uint256 pointX2, uint256 pointY2, uint256 pointZ2) external pure returns (uint256 resultX, uint256 resultY, uint256 resultZ);Fields
pointX1: U256pointY1: U256pointZ1: U256pointX2: U256pointY2: U256pointZ2: U256Trait Implementations
Sourceimpl CheatcodeDef for ecAddProjectiveCall
impl CheatcodeDef for ecAddProjectiveCall
Sourceimpl Clone for ecAddProjectiveCall
impl Clone for ecAddProjectiveCall
Sourcefn clone(&self) -> ecAddProjectiveCall
fn clone(&self) -> ecAddProjectiveCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ecAddProjectiveCall
impl Debug for ecAddProjectiveCall
Sourceimpl JsonAbiExt for ecAddProjectiveCall
impl JsonAbiExt for ecAddProjectiveCall
Sourceimpl SolCall for ecAddProjectiveCall
impl SolCall for ecAddProjectiveCall
Sourceconst SIGNATURE: &'static str = "ecAddProjective(uint256,uint256,uint256,uint256,uint256,uint256)"
const SIGNATURE: &'static str = "ecAddProjective(uint256,uint256,uint256,uint256,uint256,uint256)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<256>, Uint<256>, Uint<256>, Uint<256>, Uint<256>, Uint<256>)
type Parameters<'a> = (Uint<256>, Uint<256>, Uint<256>, Uint<256>, Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<ecAddProjectiveCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<ecAddProjectiveCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = ecAddProjectiveReturn
type Return = ecAddProjectiveReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Uint<256>, Uint<256>, Uint<256>)
type ReturnTuple<'a> = (Uint<256>, Uint<256>, Uint<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<ecAddProjectiveCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<ecAddProjectiveCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self::Return>
fn abi_decode_returns_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self::Return>
ABI-decodes this call’s return values with a custom decoder configuration.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self, Error>
fn abi_decode_raw_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self, Error>
ABI-decodes this call’s arguments with a custom decoder configuration,
without its selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self, Error>
fn abi_decode_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self, Error>
ABI-decodes this call’s arguments with a custom decoder configuration.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.