pub struct eth_getProofCall {
pub target: Address,
pub slots: Vec<FixedBytes<32>>,
pub blockNumber: U256,
}Expand description
Gets the EIP-1186 account and storage proof of target at blockNumber from the active fork.
The proof is fetched from the fork’s RPC endpoint and does not reflect local state changes.
Function with signature eth_getProof(address,bytes32[],uint256) and selector 0xcd502c82.
function eth_getProof(address target, bytes32[] calldata slots, uint256 blockNumber) external view returns (EthGetProof memory proof);Fields
target: Addressslots: Vec<FixedBytes<32>>blockNumber: U256Trait Implementations
Sourceimpl CheatcodeDef for eth_getProofCall
impl CheatcodeDef for eth_getProofCall
Sourceimpl Clone for eth_getProofCall
impl Clone for eth_getProofCall
Sourceimpl Debug for eth_getProofCall
impl Debug for eth_getProofCall
Sourceimpl JsonAbiExt for eth_getProofCall
impl JsonAbiExt for eth_getProofCall
Sourceimpl SolCall for eth_getProofCall
impl SolCall for eth_getProofCall
Sourceconst SIGNATURE: &'static str = "eth_getProof(address,bytes32[],uint256)"
const SIGNATURE: &'static str = "eth_getProof(address,bytes32[],uint256)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Array<FixedBytes<32>>, Uint<256>)
type Parameters<'a> = (Address, Array<FixedBytes<32>>, Uint<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<eth_getProofCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<eth_getProofCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = <EthGetProof as SolType>::RustType
type Return = <EthGetProof as SolType>::RustType
The function’s return struct.
Sourcetype ReturnTuple<'a> = (EthGetProof,)
type ReturnTuple<'a> = (EthGetProof,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<eth_getProofCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<eth_getProofCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self::Return>
fn abi_decode_returns_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self::Return>
ABI-decodes this call’s return values with a custom decoder configuration. Read more
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self, Error>
fn abi_decode_raw_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self, Error>
ABI-decodes this call’s arguments with a custom decoder configuration,
without its selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self, Error>
fn abi_decode_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self, Error>
ABI-decodes this call’s arguments with a custom decoder configuration.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.