pub struct expectCall_1Return {}Expand description
Expects given number of calls to an address with the specified calldata.
Container type for the return parameters of the expectCall(address,bytes,uint64) function.
Implementations
Sourceimpl expectCall_1Return
impl expectCall_1Return
fn _tokenize(&self) -> <expectCall_1Call as SolCall>::ReturnToken<'_>