pub struct expectKeychainVerifiedCall {
pub account: Address,
pub digest: FixedBytes<32>,
pub signature: Bytes,
}Expand description
Expects a call to SignatureVerifier.verifyKeychain(account, digest, signature).
Function with signature expectKeychainVerified(address,bytes32,bytes) and selector 0x3040e515.
function expectKeychainVerified(address account, bytes32 digest, bytes calldata signature) external;Fields
account: Addressdigest: FixedBytes<32>signature: BytesTrait Implementations
Sourceimpl Clone for expectKeychainVerifiedCall
impl Clone for expectKeychainVerifiedCall
Sourcefn clone(&self) -> expectKeychainVerifiedCall
fn clone(&self) -> expectKeychainVerifiedCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for expectKeychainVerifiedCall
impl Debug for expectKeychainVerifiedCall
Sourceimpl JsonAbiExt for expectKeychainVerifiedCall
impl JsonAbiExt for expectKeychainVerifiedCall
Sourceimpl SolCall for expectKeychainVerifiedCall
impl SolCall for expectKeychainVerifiedCall
Sourceconst SIGNATURE: &'static str = "expectKeychainVerified(address,bytes32,bytes)"
const SIGNATURE: &'static str = "expectKeychainVerified(address,bytes32,bytes)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, FixedBytes<32>, Bytes)
type Parameters<'a> = (Address, FixedBytes<32>, Bytes)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<expectKeychainVerifiedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<expectKeychainVerifiedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = expectKeychainVerifiedReturn
type Return = expectKeychainVerifiedReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<expectKeychainVerifiedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<expectKeychainVerifiedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.