pub struct expectPartialRevert_1Return {}Expand description
Expects an error on next call to reverter address, that starts with the revert data.
See expectRevert(address) for reverter matching semantics.
Container type for the return parameters of the expectPartialRevert(bytes4,address) function.
Implementations
Sourceimpl expectPartialRevert_1Return
impl expectPartialRevert_1Return
fn _tokenize(&self) -> <expectPartialRevert_1Call as SolCall>::ReturnToken<'_>