pub struct expectTip20LogoURIUpdatedCall {
pub token: Address,
pub updater: Address,
pub newLogoURI: String,
}Expand description
Expects a TIP-20 LogoURIUpdated(address indexed updater, string newLogoURI) event.
Function with signature expectTip20LogoURIUpdated(address,address,string) and selector 0x4e134a2c.
function expectTip20LogoURIUpdated(address token, address updater, string calldata newLogoURI) external;Fields
token: Addressupdater: AddressnewLogoURI: StringTrait Implementations
Sourceimpl Clone for expectTip20LogoURIUpdatedCall
impl Clone for expectTip20LogoURIUpdatedCall
Sourcefn clone(&self) -> expectTip20LogoURIUpdatedCall
fn clone(&self) -> expectTip20LogoURIUpdatedCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl JsonAbiExt for expectTip20LogoURIUpdatedCall
impl JsonAbiExt for expectTip20LogoURIUpdatedCall
Sourceimpl SolCall for expectTip20LogoURIUpdatedCall
impl SolCall for expectTip20LogoURIUpdatedCall
Sourceconst SIGNATURE: &'static str = "expectTip20LogoURIUpdated(address,address,string)"
const SIGNATURE: &'static str = "expectTip20LogoURIUpdated(address,address,string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Address, String)
type Parameters<'a> = (Address, Address, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<expectTip20LogoURIUpdatedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<expectTip20LogoURIUpdatedCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = expectTip20LogoURIUpdatedReturn
type Return = expectTip20LogoURIUpdatedReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<expectTip20LogoURIUpdatedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<expectTip20LogoURIUpdatedCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.