pub struct ffiBytesReturn {
pub result: Bytes,
}Expand description
Performs a foreign function call via the terminal and decodes the output as hex bytes.
Container type for the return parameters of the ffiBytes(string[]) function.
Fields
result: BytesTrait Implementations
Sourceimpl Clone for ffiBytesReturn
impl Clone for ffiBytesReturn
Sourcefn clone(&self) -> ffiBytesReturn
fn clone(&self) -> ffiBytesReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for ffiBytesReturn
impl RefUnwindSafe for ffiBytesReturn
impl Send for ffiBytesReturn
impl Sync for ffiBytesReturn
impl Unpin for ffiBytesReturn
impl UnsafeUnpin for ffiBytesReturn
impl UnwindSafe for ffiBytesReturn