pub struct ffiStringCall {
pub commandInput: Vec<String>,
}Expand description
Performs a foreign function call via the terminal and returns the output as a string.
Function with signature ffiString(string[]) and selector 0x0d0d2f41.
function ffiString(string[] calldata commandInput) external returns (string memory result);Fields
commandInput: Vec<String>Trait Implementations
Sourceimpl CheatcodeDef for ffiStringCall
impl CheatcodeDef for ffiStringCall
Sourceimpl Clone for ffiStringCall
impl Clone for ffiStringCall
Sourcefn clone(&self) -> ffiStringCall
fn clone(&self) -> ffiStringCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ffiStringCall
impl Debug for ffiStringCall
Sourceimpl JsonAbiExt for ffiStringCall
impl JsonAbiExt for ffiStringCall
Sourceimpl SolCall for ffiStringCall
impl SolCall for ffiStringCall
Sourcetype Parameters<'a> = (Array<String>,)
type Parameters<'a> = (Array<String>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<ffiStringCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<ffiStringCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (String,)
type ReturnTuple<'a> = (String,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<ffiStringCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<ffiStringCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self::Return>
fn abi_decode_returns_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self::Return>
ABI-decodes this call’s return values with a custom decoder configuration.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self, Error>
fn abi_decode_raw_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self, Error>
ABI-decodes this call’s arguments with a custom decoder configuration,
without its selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_with_config(
data: &[u8],
config: AbiDecoderConfig,
) -> Result<Self, Error>
fn abi_decode_with_config( data: &[u8], config: AbiDecoderConfig, ) -> Result<Self, Error>
ABI-decodes this call’s arguments with a custom decoder configuration.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.