pub struct ffiUintReturn {
pub result: U256,
}Expand description
Performs a foreign function call via the terminal and parses the output as a uint256.
Container type for the return parameters of the ffiUint(string[]) function.
Fields
result: U256Trait Implementations
Sourceimpl Clone for ffiUintReturn
impl Clone for ffiUintReturn
Sourcefn clone(&self) -> ffiUintReturn
fn clone(&self) -> ffiUintReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ffiUintReturn
impl RefUnwindSafe for ffiUintReturn
impl Send for ffiUintReturn
impl Sync for ffiUintReturn
impl Unpin for ffiUintReturn
impl UnsafeUnpin for ffiUintReturn
impl UnwindSafe for ffiUintReturn