pub struct getMappingKeyAndParentOfReturn {
pub found: bool,
pub key: FixedBytes<32>,
pub parent: FixedBytes<32>,
}Expand description
Gets the map key and parent of a mapping at a given slot, for a given address.
Container type for the return parameters of the getMappingKeyAndParentOf(address,bytes32) function.
Fields
found: boolkey: FixedBytes<32>parent: FixedBytes<32>Implementations
Sourceimpl getMappingKeyAndParentOfReturn
impl getMappingKeyAndParentOfReturn
fn _tokenize( &self, ) -> <getMappingKeyAndParentOfCall as SolCall>::ReturnToken<'_>