pub struct isImplicitlyApprovedReturn {
pub implicitlyApproved: bool,
}Expand description
Returns true if spender is on the active Tempo hardfork’s implicit-approval list,
meaning it can pull TIP-20 tokens from msg.sender without a prior approve().
Returns false on non-Tempo networks.
Container type for the return parameters of the isImplicitlyApproved(address) function.
Fields
implicitlyApproved: boolTrait Implementations
Sourceimpl Clone for isImplicitlyApprovedReturn
impl Clone for isImplicitlyApprovedReturn
Sourcefn clone(&self) -> isImplicitlyApprovedReturn
fn clone(&self) -> isImplicitlyApprovedReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for isImplicitlyApprovedReturn
impl RefUnwindSafe for isImplicitlyApprovedReturn
impl Send for isImplicitlyApprovedReturn
impl Sync for isImplicitlyApprovedReturn
impl Unpin for isImplicitlyApprovedReturn
impl UnsafeUnpin for isImplicitlyApprovedReturn
impl UnwindSafe for isImplicitlyApprovedReturn