pub struct lastFrameGasReturn {
pub gas: <Gas as SolType>::RustType,
}Expand description
Gets the gas used in the last call or create from the callee perspective.
Container type for the return parameters of the lastFrameGas() function.
Fields
gas: <Gas as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for lastFrameGasReturn
impl Clone for lastFrameGasReturn
Sourcefn clone(&self) -> lastFrameGasReturn
fn clone(&self) -> lastFrameGasReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for lastFrameGasReturn
impl RefUnwindSafe for lastFrameGasReturn
impl Send for lastFrameGasReturn
impl Sync for lastFrameGasReturn
impl Unpin for lastFrameGasReturn
impl UnsafeUnpin for lastFrameGasReturn
impl UnwindSafe for lastFrameGasReturn