pub struct mockCall_4Return {}Expand description
Mocks a call to an address, returning specified data. Calldata can either be strict or a partial match, e.g. if you only pass a Solidity selector to the expected calldata, then the entire Solidity function will be mocked.
Overload to control whether code is injected into callee. The other overloads etch a
single byte into an empty account to circumvent Solidity’s extcodesize check, with the
side effect that unmocked calls to it no longer revert; injectCode = false leaves the
account codeless, so unmocked calls to it revert in the caller. Mocked calls that return
data still succeed, as Solidity checks returndatasize() instead of extcodesize() when
return data is expected, but mocked calls to functions without return values may still
revert in the caller due to the extcodesize check.
Container type for the return parameters of the mockCall(address,bytes,bytes,bool) function.
Implementations
Sourceimpl mockCall_4Return
impl mockCall_4Return
fn _tokenize(&self) -> <mockCall_4Call as SolCall>::ReturnToken<'_>