pub struct parseJsonArrayLengthCall {
pub json: String,
pub key: String,
}Expand description
Returns the length of the JSON array at key.
Function with signature parseJsonArrayLength(string,string) and selector 0xcdb6e4ac.
function parseJsonArrayLength(string calldata json, string calldata key) external pure returns (uint256 length);Fields
json: Stringkey: StringTrait Implementations
Sourceimpl Clone for parseJsonArrayLengthCall
impl Clone for parseJsonArrayLengthCall
Sourcefn clone(&self) -> parseJsonArrayLengthCall
fn clone(&self) -> parseJsonArrayLengthCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for parseJsonArrayLengthCall
impl Debug for parseJsonArrayLengthCall
Sourceimpl JsonAbiExt for parseJsonArrayLengthCall
impl JsonAbiExt for parseJsonArrayLengthCall
Sourceimpl SolCall for parseJsonArrayLengthCall
impl SolCall for parseJsonArrayLengthCall
Sourceconst SIGNATURE: &'static str = "parseJsonArrayLength(string,string)"
const SIGNATURE: &'static str = "parseJsonArrayLength(string,string)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (String, String)
type Parameters<'a> = (String, String)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<parseJsonArrayLengthCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<parseJsonArrayLengthCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (Uint<256>,)
type ReturnTuple<'a> = (Uint<256>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<parseJsonArrayLengthCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<parseJsonArrayLengthCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.