pub struct parseJsonBytesArray_1Return {
pub _0: Vec<Bytes>,
}Expand description
Parses a string of JSON data at key and coerces it to bytes[], or returns defaultValue if the key does not exist.
Container type for the return parameters of the parseJsonBytesArray(string,string,bytes[]) function.
Fields
_0: Vec<Bytes>Trait Implementations
Sourceimpl Clone for parseJsonBytesArray_1Return
impl Clone for parseJsonBytesArray_1Return
Sourcefn clone(&self) -> parseJsonBytesArray_1Return
fn clone(&self) -> parseJsonBytesArray_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseJsonBytesArray_1Return
impl RefUnwindSafe for parseJsonBytesArray_1Return
impl Send for parseJsonBytesArray_1Return
impl Sync for parseJsonBytesArray_1Return
impl Unpin for parseJsonBytesArray_1Return
impl UnsafeUnpin for parseJsonBytesArray_1Return
impl UnwindSafe for parseJsonBytesArray_1Return