pub struct parseJsonBytes_0Return {
pub _0: Bytes,
}Expand description
Parses a string of JSON data at key and coerces it to bytes.
Container type for the return parameters of the parseJsonBytes(string,string) function.
Fields
_0: BytesTrait Implementations
Sourceimpl Clone for parseJsonBytes_0Return
impl Clone for parseJsonBytes_0Return
Sourcefn clone(&self) -> parseJsonBytes_0Return
fn clone(&self) -> parseJsonBytes_0Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for parseJsonBytes_0Return
impl RefUnwindSafe for parseJsonBytes_0Return
impl Send for parseJsonBytes_0Return
impl Sync for parseJsonBytes_0Return
impl Unpin for parseJsonBytes_0Return
impl UnsafeUnpin for parseJsonBytes_0Return
impl UnwindSafe for parseJsonBytes_0Return