pub struct parseJsonInt_1Return {
pub _0: I256,
}Expand description
Parses a string of JSON data at key and coerces it to int256, or returns defaultValue if the key does not exist.
Container type for the return parameters of the parseJsonInt(string,string,int256) function.
Fields
_0: I256Trait Implementations
Sourceimpl Clone for parseJsonInt_1Return
impl Clone for parseJsonInt_1Return
Sourcefn clone(&self) -> parseJsonInt_1Return
fn clone(&self) -> parseJsonInt_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseJsonInt_1Return
impl RefUnwindSafe for parseJsonInt_1Return
impl Send for parseJsonInt_1Return
impl Sync for parseJsonInt_1Return
impl Unpin for parseJsonInt_1Return
impl UnsafeUnpin for parseJsonInt_1Return
impl UnwindSafe for parseJsonInt_1Return