pub struct parseJsonUint_0Return {
pub _0: U256,
}Expand description
Parses a string of JSON data at key and coerces it to uint256.
Container type for the return parameters of the parseJsonUint(string,string) function.
Fields
_0: U256Trait Implementations
Sourceimpl Clone for parseJsonUint_0Return
impl Clone for parseJsonUint_0Return
Sourcefn clone(&self) -> parseJsonUint_0Return
fn clone(&self) -> parseJsonUint_0Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseJsonUint_0Return
impl RefUnwindSafe for parseJsonUint_0Return
impl Send for parseJsonUint_0Return
impl Sync for parseJsonUint_0Return
impl Unpin for parseJsonUint_0Return
impl UnsafeUnpin for parseJsonUint_0Return
impl UnwindSafe for parseJsonUint_0Return