pub struct parseTomlAddress_0Return {
pub _0: Address,
}Expand description
Parses a string of TOML data at key and coerces it to address.
Container type for the return parameters of the parseTomlAddress(string,string) function.
Fields
_0: AddressTrait Implementations
Sourceimpl Clone for parseTomlAddress_0Return
impl Clone for parseTomlAddress_0Return
Sourcefn clone(&self) -> parseTomlAddress_0Return
fn clone(&self) -> parseTomlAddress_0Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseTomlAddress_0Return
impl RefUnwindSafe for parseTomlAddress_0Return
impl Send for parseTomlAddress_0Return
impl Sync for parseTomlAddress_0Return
impl Unpin for parseTomlAddress_0Return
impl UnsafeUnpin for parseTomlAddress_0Return
impl UnwindSafe for parseTomlAddress_0Return