pub struct parseTomlBytes32Array_0Return {
pub _0: Vec<FixedBytes<32>>,
}Expand description
Parses a string of TOML data at key and coerces it to bytes32[].
Container type for the return parameters of the parseTomlBytes32Array(string,string) function.
Fields
_0: Vec<FixedBytes<32>>Trait Implementations
Sourceimpl Clone for parseTomlBytes32Array_0Return
impl Clone for parseTomlBytes32Array_0Return
Sourcefn clone(&self) -> parseTomlBytes32Array_0Return
fn clone(&self) -> parseTomlBytes32Array_0Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseTomlBytes32Array_0Return
impl RefUnwindSafe for parseTomlBytes32Array_0Return
impl Send for parseTomlBytes32Array_0Return
impl Sync for parseTomlBytes32Array_0Return
impl Unpin for parseTomlBytes32Array_0Return
impl UnsafeUnpin for parseTomlBytes32Array_0Return
impl UnwindSafe for parseTomlBytes32Array_0Return