pub struct parseTomlBytes32Array_1Return {
pub _0: Vec<FixedBytes<32>>,
}Expand description
Parses a string of TOML data at key and coerces it to bytes32[], or returns defaultValue if the key does not exist.
Container type for the return parameters of the parseTomlBytes32Array(string,string,bytes32[]) function.
Fields
_0: Vec<FixedBytes<32>>Trait Implementations
Sourceimpl Clone for parseTomlBytes32Array_1Return
impl Clone for parseTomlBytes32Array_1Return
Sourcefn clone(&self) -> parseTomlBytes32Array_1Return
fn clone(&self) -> parseTomlBytes32Array_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseTomlBytes32Array_1Return
impl RefUnwindSafe for parseTomlBytes32Array_1Return
impl Send for parseTomlBytes32Array_1Return
impl Sync for parseTomlBytes32Array_1Return
impl Unpin for parseTomlBytes32Array_1Return
impl UnsafeUnpin for parseTomlBytes32Array_1Return
impl UnwindSafe for parseTomlBytes32Array_1Return