pub struct parseTomlBytes_0Return {
pub _0: Bytes,
}Expand description
Parses a string of TOML data at key and coerces it to bytes.
Container type for the return parameters of the parseTomlBytes(string,string) function.
Fields
_0: BytesTrait Implementations
Sourceimpl Clone for parseTomlBytes_0Return
impl Clone for parseTomlBytes_0Return
Sourcefn clone(&self) -> parseTomlBytes_0Return
fn clone(&self) -> parseTomlBytes_0Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for parseTomlBytes_0Return
impl RefUnwindSafe for parseTomlBytes_0Return
impl Send for parseTomlBytes_0Return
impl Sync for parseTomlBytes_0Return
impl Unpin for parseTomlBytes_0Return
impl UnsafeUnpin for parseTomlBytes_0Return
impl UnwindSafe for parseTomlBytes_0Return