pub struct parseTomlIntArray_1Return {
pub _0: Vec<I256>,
}Expand description
Parses a string of TOML data at key and coerces it to int256[], or returns defaultValue if the key does not exist.
Container type for the return parameters of the parseTomlIntArray(string,string,int256[]) function.
Fields
_0: Vec<I256>Trait Implementations
Sourceimpl Clone for parseTomlIntArray_1Return
impl Clone for parseTomlIntArray_1Return
Sourcefn clone(&self) -> parseTomlIntArray_1Return
fn clone(&self) -> parseTomlIntArray_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for parseTomlIntArray_1Return
impl RefUnwindSafe for parseTomlIntArray_1Return
impl Send for parseTomlIntArray_1Return
impl Sync for parseTomlIntArray_1Return
impl Unpin for parseTomlIntArray_1Return
impl UnsafeUnpin for parseTomlIntArray_1Return
impl UnwindSafe for parseTomlIntArray_1Return