pub struct rpcJson_1Return {
pub data: String,
}Expand description
Performs an Ethereum JSON-RPC request to the given endpoint and returns the JSON result.
Container type for the return parameters of the rpcJson(string,string,string) function.
Fields
data: StringTrait Implementations
Sourceimpl Clone for rpcJson_1Return
impl Clone for rpcJson_1Return