pub struct setEvmVersionReturn {}Expand description
Selects the test or script execution hardfork, e.g. berlin, cancun, or tempo:T7.
Uses the active network’s version mappings and gas schedule. Does not change the network
or Solidity compiler target. On Tempo, runtime changes do not rebuild instructions or
precompiles; configure hardfork before execution to select a different revision.
Note: The execution evm version is not the same as the compilation one.
Container type for the return parameters of the setEvmVersion(string) function.
Implementations
Sourceimpl setEvmVersionReturn
impl setEvmVersionReturn
fn _tokenize(&self) -> <setEvmVersionCall as SolCall>::ReturnToken<'_>