setLogoURIReturn

Struct setLogoURIReturn 

pub struct setLogoURIReturn {}
Sets a TIP-20 token’s logo URI directly in storage. This bypasses the token admin check, but still validates the URI against T5 constraints. Container type for the return parameters of the setLogoURI(address,string) function.

Implementations

Source

impl setLogoURIReturn

fn _tokenize(&self) -> <setLogoURICall as SolCall>::ReturnToken<'_>