pub struct setTip20LogoURIReturn {}Expand description
Sets a TIP-20 token’s logo URI directly in storage.
This bypasses the token admin check, but still validates the URI against T5 constraints.
Container type for the return parameters of the setTip20LogoURI(address,string) function.
Implementations
Sourceimpl setTip20LogoURIReturn
impl setTip20LogoURIReturn
fn _tokenize(&self) -> <setTip20LogoURICall as SolCall>::ReturnToken<'_>