pub struct signKeychainAdminCall {
pub privateKey: U256,
pub account: Address,
pub digest: FixedBytes<32>,
}Expand description
Signs digest as a Tempo V2 keychain signature for account using a root or admin secp256k1 key.
Returns the encoded signature bytes accepted by SignatureVerifier.verifyKeychainAdmin.
The supplied digest should already be domain-separated with chain ID, contract address,
and account address.
Function with signature signKeychainAdmin(uint256,address,bytes32) and selector 0xbc5fb2f7.
function signKeychainAdmin(uint256 privateKey, address account, bytes32 digest) external pure returns (bytes memory signature);Fields
privateKey: U256account: Addressdigest: FixedBytes<32>Trait Implementations
Sourceimpl CheatcodeDef for signKeychainAdminCall
impl CheatcodeDef for signKeychainAdminCall
Sourceimpl Clone for signKeychainAdminCall
impl Clone for signKeychainAdminCall
Sourcefn clone(&self) -> signKeychainAdminCall
fn clone(&self) -> signKeychainAdminCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for signKeychainAdminCall
impl Debug for signKeychainAdminCall
Sourceimpl JsonAbiExt for signKeychainAdminCall
impl JsonAbiExt for signKeychainAdminCall
Sourceimpl SolCall for signKeychainAdminCall
impl SolCall for signKeychainAdminCall
Sourceconst SIGNATURE: &'static str = "signKeychainAdmin(uint256,address,bytes32)"
const SIGNATURE: &'static str = "signKeychainAdmin(uint256,address,bytes32)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<256>, Address, FixedBytes<32>)
type Parameters<'a> = (Uint<256>, Address, FixedBytes<32>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<signKeychainAdminCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<signKeychainAdminCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype ReturnTuple<'a> = (Bytes,)
type ReturnTuple<'a> = (Bytes,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<signKeychainAdminCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<signKeychainAdminCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.