pub struct signKeychainAdminReturn {
pub signature: Bytes,
}Expand description
Signs digest as a Tempo V2 keychain signature for account using a root or admin secp256k1 key.
Returns the encoded signature bytes accepted by SignatureVerifier.verifyKeychainAdmin.
The supplied digest should already be domain-separated with chain ID, contract address,
and account address.
Container type for the return parameters of the signKeychainAdmin(uint256,address,bytes32) function.
Fields
signature: BytesTrait Implementations
Sourceimpl Clone for signKeychainAdminReturn
impl Clone for signKeychainAdminReturn
Sourcefn clone(&self) -> signKeychainAdminReturn
fn clone(&self) -> signKeychainAdminReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for signKeychainAdminReturn
impl RefUnwindSafe for signKeychainAdminReturn
impl Send for signKeychainAdminReturn
impl Sync for signKeychainAdminReturn
impl Unpin for signKeychainAdminReturn
impl UnsafeUnpin for signKeychainAdminReturn
impl UnwindSafe for signKeychainAdminReturn