pub struct snapshotGasLastFrame_1Return {
pub gasUsed: U256,
}Expand description
Snapshot capture the gas usage of the last call or create by name in a group from the callee perspective.
Container type for the return parameters of the snapshotGasLastFrame(string,string) function.
Fields
gasUsed: U256Trait Implementations
Sourceimpl Clone for snapshotGasLastFrame_1Return
impl Clone for snapshotGasLastFrame_1Return
Sourcefn clone(&self) -> snapshotGasLastFrame_1Return
fn clone(&self) -> snapshotGasLastFrame_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for snapshotGasLastFrame_1Return
impl RefUnwindSafe for snapshotGasLastFrame_1Return
impl Send for snapshotGasLastFrame_1Return
impl Sync for snapshotGasLastFrame_1Return
impl Unpin for snapshotGasLastFrame_1Return
impl UnsafeUnpin for snapshotGasLastFrame_1Return
impl UnwindSafe for snapshotGasLastFrame_1Return