pub struct transact_1Return {}Expand description
Fetches the given transaction from the given fork and executes it on the current state.
Container type for the return parameters of the transact(uint256,bytes32) function.
Implementations
Sourceimpl transact_1Return
impl transact_1Return
fn _tokenize(&self) -> <transact_1Call as SolCall>::ReturnToken<'_>