pub struct eth_getProofReturn {
pub proof: <EthGetProof as SolType>::RustType,
}Expand description
Gets the EIP-1186 account and storage proof of target at blockNumber from the active fork.
The proof is fetched from the fork’s RPC endpoint and does not reflect local state changes.
Container type for the return parameters of the eth_getProof(address,bytes32[],uint256) function.
Fields
proof: <EthGetProof as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for eth_getProofReturn
impl Clone for eth_getProofReturn