pub struct rpcJson_1Return {
pub data: String,
}Expand description
Performs an Ethereum JSON-RPC request to the given endpoint and returns the JSON result.
Container type for the return parameters of the rpcJson(string,string,string) function.
Fields
data: StringTrait Implementations
Sourceimpl Clone for rpcJson_1Return
impl Clone for rpcJson_1Return
Sourcefn clone(&self) -> rpcJson_1Return
fn clone(&self) -> rpcJson_1Return
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for rpcJson_1Return
impl RefUnwindSafe for rpcJson_1Return
impl Send for rpcJson_1Return
impl Sync for rpcJson_1Return
impl Unpin for rpcJson_1Return
impl UnsafeUnpin for rpcJson_1Return
impl UnwindSafe for rpcJson_1Return